@@ -12,7 +12,7 @@ import locapip
 @click.option('--logging', type=click.Path(file_okay=True, dir_okay=False))
 def main(port: int, config, logging):
     if logging is not None:
-        locapip.set_logging(logging)
+        locapip.init_logging(logging)
 
     if config is not None:
         locapip.config.update(json.loads(Path(config).read_text()))
